This packages contains utility code used for Functional Programming, such as:
- `spark_frame.fp.PrintableFunction`: Wrapper class for lambda function that makes debugging much 
    easier when composing them together.
- `spark_frame.fp.compose`: method that allows to compose two PrintableFunctions together.
- `spark_frame.fp.higher_order`: package that provides and can generate several reusable PrintableFunctions.
